@@ -14,9 +14,9 @@ from cognite.client.data_classes.geospatial import (
     FeatureList,
     FeatureType,
     FeatureTypeList,
+    FeatureTypePatch,
     FeatureTypeUpdate,
     OrderSpec,
-    FeatureTypePatch,
 )
 from cognite.client.exceptions import CogniteConnectionError
 
@@ -282,7 +282,7 @@ class GeospatialAPI(APIClient):
 
                 >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
-                >>> c.geospatial.delete_feature("my_feature_type", external_id=my_feature)
+                >>> c.geospatial.delete_features("my_feature_type", external_id=my_feature)
         """
         resource_path = self._feature_resource_path(feature_type_external_id)
         self._delete_multiple(external_ids=external_id, wrap_ids=True, resource_path=resource_path)
@@ -310,7 +310,7 @@ class GeospatialAPI(APIClient):
 
                 >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
-                >>> c.geospatial.retrieve_feature("my_feature_type", external_id="my_feature")
+                >>> c.geospatial.retrieve_features("my_feature_type", external_id="my_feature")
         """
         resource_path = self._feature_resource_path(feature_type_external_id)
         return self._retrieve_multiple(
